/*
 * Project name:
     Button (Demonstration of using Button Library)
 * Copyright:
     (c) mikroElektronika, 2010.
 * Revision History:
     20100429:
       - Initial release;
 * Description:
     This program demonstrates usage on-board button as PORTD input.
     On every RD0 one-to-zero transition PORTB is inverted.
 * Test configuration:
     MCU:             dsPIC24FJ96GA010
                      http://ww1.microchip.com/downloads/en/DeviceDoc/39747e.pdf
     dev.board:       LV24-33 v6 - ac:Button
                      http://www.mikroe.com/eng/products/view/430/lv-24-33-v6-development-system
     Oscillator:      XT, 8.00000 MHz
     Ext. Modules:    None.
     SW:              mikroC PRO for dsPIC30/33 and PIC24
                      http://www.mikroe.com/en/compilers/mikroc/pro/dspic/
 * NOTES:
     - Turn ON the PORTB LEDs at SW13.
     - Put button jumper (J17) into VCC position and pull-down PORTD.
 */

unsigned int oldstate;

void main() {
  ADPCFG = 0xFFFF;                             // initialize AN pins as digital
  TRISD = 0xFFFF;                              // initialize PORTD as input
  TRISB = 0x0000;                              // initialize PORTB as output
  LATB  = 0xFF00;

  do {
    if (Button(&PORTD, 0, 1, 1))               // detect logical one state
      oldstate = 1;
    if (oldstate && Button(&PORTD, 0, 1, 0)) { // detect logical one to logical zero transition
      LATB = ~LATB;                            // toggle portb
      oldstate = 0;
    }
  } while(1);
}