/*
 * Project name:
     GLCD_Test (Demonstration of the GLCD library routines)
 * Copyright:
     (c) mikroElektronika, 2010.
 * Revision History:
     20100429:
       - Initial release;
 * Description:
     This is a simple demonstration of the GLCD library routines:
     - Init and Clear (pattern fill)
     - Image display
     - Basic geometry - lines, circles, boxes and rectangles
     - Text display and handling
 * Test configuration:
     MCU:             dsPIC24FJ96GA010
                      http://ww1.microchip.com/downloads/en/DeviceDoc/39747e.pdf
     dev.board:       LV24-33 v6 - ac:GLCD
                      http://www.mikroe.com/eng/products/view/430/lv-24-33-v6-development-system
     Oscillator:      XT, 8.00000 MHz
     Ext. Modules:    GLCD 128x64, KS108/107 controller
                      http://www.mikroe.com/en/tools/components/#other
     SW:              mikroC PRO for dsPIC30/33 and PIC24
                      http://www.mikroe.com/en/compilers/mikroc/pro/dspic/
 * NOTES:
   - Turn on GLCD backlight at SW17.8. (board specific)
 */

//Declarations------------------------------------------------------------------
const code char truck_bmp[1024];
//--------------------------------------------------------------end-declarations

// Glcd module connections
sbit GLCD_D7 at RD7_bit;
sbit GLCD_D6 at RD6_bit;
sbit GLCD_D5 at RD5_bit;
sbit GLCD_D4 at RD4_bit;
sbit GLCD_D3 at RD3_bit;
sbit GLCD_D2 at RD2_bit;
sbit GLCD_D1 at RD1_bit;
sbit GLCD_D0 at RD0_bit;
sbit GLCD_D7_Direction at TRISD7_bit;
sbit GLCD_D6_Direction at TRISD6_bit;
sbit GLCD_D5_Direction at TRISD5_bit;
sbit GLCD_D4_Direction at TRISD4_bit;
sbit GLCD_D3_Direction at TRISD3_bit;
sbit GLCD_D2_Direction at TRISD2_bit;
sbit GLCD_D1_Direction at TRISD1_bit;
sbit GLCD_D0_Direction at TRISD0_bit;

sbit GLCD_CS1 at LATB2_bit;
sbit GLCD_CS2 at LATB3_bit;
sbit GLCD_RS  at LATB4_bit;
sbit GLCD_RW  at LATB5_bit;
sbit GLCD_EN  at LATB6_bit;
sbit GLCD_RST at LATB7_bit;
sbit GLCD_CS1_Direction at TRISB2_bit;
sbit GLCD_CS2_Direction at TRISB3_bit;
sbit GLCD_RS_Direction  at TRISB4_bit;
sbit GLCD_RW_Direction  at TRISB5_bit;
sbit GLCD_EN_Direction  at TRISB6_bit;
sbit GLCD_RST_Direction at TRISB7_bit;
// End Glcd module connections

void delay2S(){                                  // 2 seconds delay function
  Delay_ms(2000);
}

void main() {
  unsigned short ii;
  char *someText;

  #define COMPLETE_EXAMPLE                       // Comment this line to make simpler/smaller example
  ADPCFG = 0xFFFF;                               // Configure AN pins as digital

  Glcd_Init();                                   // Initialize GLCD
  Glcd_Fill(0x00);                               // Clear GLCD

  while(1) {
    #ifdef COMPLETE_EXAMPLE
      Glcd_Image(truck_bmp);                     // Draw image
      delay2S(); delay2S();
    #endif

    Glcd_Fill(0x00);                             // Clear GLCD

    Glcd_Box(62,40,124,56,1);                    // Draw box
    Glcd_Rectangle(5,5,84,35,1);                 // Draw rectangle
    Glcd_Line(0, 0, 127, 63, 1);                 // Draw line
    delay2S();

    for(ii = 5; ii < 60; ii+=5 ){                // Draw horizontal and vertical lines
      Delay_ms(250);
      Glcd_V_Line(2, 54, ii, 1);
      Glcd_H_Line(2, 120, ii, 1);
    }

    delay2S();

    Glcd_Fill(0x00);                             // Clear GLCD
    #ifdef COMPLETE_EXAMPLE
      Glcd_Set_Font(Font_Glcd_Character8x7, 8, 7, 32);     // Choose font, see __Lib_GLCDFonts.c in Uses folder
    #endif
    Glcd_Write_Text("mikroE", 1, 7, 2);          // Write string

    for (ii = 1; ii <= 10; ii++)                 // Draw circles
      Glcd_Circle(63,32, 3*ii, 1);
    delay2S();

    Glcd_Box(10,20, 70,63, 2);                   // Draw box
    delay2S();

    #ifdef COMPLETE_EXAMPLE
      Glcd_Fill(0xFF);                           // Fill GLCD

      Glcd_Set_Font(Font_Glcd_Character8x7, 8, 7, 32);     // Change font
      someText = "8x7 Font";
      Glcd_Write_Text(someText, 5, 0, 2);        // Write string
      delay2S();

      Glcd_Set_Font(Font_Glcd_System3x5, 3, 5, 32);        // Change font
      someText = "3X5 CAPITALS ONLY";
      Glcd_Write_Text(someText, 60, 2, 2);       // Write string
      delay2S();

      Glcd_Set_Font(Font_Glcd_5x7, 5, 7, 32);          // Change font
      someText = "5x7 Font";
      Glcd_Write_Text(someText, 5, 4, 2);        // Write string
      delay2S();

      Glcd_Set_Font(Font_Glcd_System5x7, 5, 7, 32); // Change font
      someText = "5x7 Font (v2)";
      Glcd_Write_Text(someText, 50, 6, 2);        // Write string
      delay2S();
    #endif
  }
}